==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a modo ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Cambiar a modo pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Conteo regresivo</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Cuidado</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Grabación no iniciada, no tiene espacio en el disco duro</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Se alcanzó el límite de espacio libre en disco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La grabación fue detenida, no tiene espacio libre en el disco</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró administrador de archivos</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instalar un administrador de archivos</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>La sesión de escritorio es una sesion de  Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Hasta el momento Wayland no es compatible. Una grabación muestra una pantalla en negro. Cierre sesión e inicie una sesión de escritorio X11</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página de inicio</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Sesion de escritorio Wayland detectada</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro Horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gira Vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover marco de ventana</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ajustes de camara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Conteo regresivo</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio de disco libre:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cuadros</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar puntero del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Detener grabación después de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segunda espera antes de grabar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Revisar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar reporte</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir la última grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir folder</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar cuando la grabación comience</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro Horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gira Vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover marco de ventana</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Resetear todas las configuraciones en el próximo inicio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencias de imágenes</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Grabaciones</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencias de imágenes</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Cuadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Cuadro siguiente</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover menú</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_419">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a modo ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Cambiar a modo pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró administrador de archivos</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instalar un administrador de archivos</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Cuidado</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Grabación no iniciada, no tiene espacio en el disco duro</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Se alcanzó el límite de espacio libre en disco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La grabación fue detenida, no tiene espacio libre en el disco</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró administrador de archivos</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instalar un administrador de archivos</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Página de inicio</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro Horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gira Vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover marco de ventana</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ajustes de camara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Conteo regresivo</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio de disco libre:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cuadros</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar puntero del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Detener grabación después de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segunda espera antes de grabar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Revisar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar reporte</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir la última grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir folder</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar cuando la grabación comience</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Giro Horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gira Vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover marco de ventana</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Resetear todas las configuraciones en el próximo inicio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencias de imágenes</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Grabaciones</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencias de imágenes</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Cuadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Cuadro siguiente</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover menú</translation>
    </message>
</context>
</TS>
